/* $Id$ */
/** \file version.h 
 *  \brief  A file simply containing the library version number.
 */

/*! LIBVCD_VERSION can as a string in programs to show what version is used. */
#define LIBVCD_VERSION "2.0.1"

/*! LIBVCD_VERSION_NUM  can be used for testing in the C preprocessor */
#define LIBVCD_VERSION_NUM 1

